coherence.upnp.core.soap_service (module) — Cohen3 0.8.0 documentation

# coherence.upnp.core.soap_service (module)

## Soap Service

SOAP is a simple Object Access Protocol, for actually calling actions. This module contains a class `UPnPPublisher` which will manage SOAP’s services.

### `errorCode`

Custom exception for class `UPnPPublisher`

### `UPnPPublisher`

A custom implementation of `twisted.web.soap.SOAPPublisher`, but removing the SOAPpy dependency.

exception `errorCode`(status)

  Bases: `Exception`

class `UPnPPublisher`(*args, **kwargs)

  Bases: `eventdispatcher.eventdispatcher.EventDispatcher`, `twisted.web.resource.Resource`, `coherence.log.LogAble`

  Based upon twisted.web.soap.SOAPPublisher and extracted to remove the SOAPpy dependency UPnP requires headers and OUT parameters to be returned in a slightly different way than the SOAPPublisher class does.

  Changed in version 0.9.0:

  - Migrated from louie/dispatcher to EventDispatcher

  - The emitted events changed:

    > - UPnPTest.Control.Client.CommandReceived => control_client_command_received

  `logCategory` = 'soap'
  `isLeaf` = 1
  `encoding` = 'UTF-8'
  `envelope_attrib` = None
  `_sendResponse`(request, response, status=200)
  `_methodNotFound`(request, methodName)
  `_gotResult`(result, request, methodName, ns)
  `_gotError`(failure, request, methodName, ns)
  `lookupFunction`(functionName)
  `render`(request)

    Handle a SOAP command.

  `decode_result`(element)